CreateBucketRequest

Struct CreateBucketRequest 

pub struct CreateBucketRequest {
    pub acl: Option<String>,
    pub bucket: String,
    pub create_bucket_configuration: Option<CreateBucketConfiguration>,
    pub grant_full_control: Option<String>,
    pub grant_read: Option<String>,
    pub grant_read_acp: Option<String>,
    pub grant_write: Option<String>,
    pub grant_write_acp: Option<String>,
    pub object_lock_enabled_for_bucket: Option<bool>,
}

Fields

acl: Option<String>

The canned ACL to apply to the bucket.

bucket: String

The name of the bucket to create.

create_bucket_configuration: Option<CreateBucketConfiguration>

The configuration information for the bucket.

grant_full_control: Option<String>

Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

grant_read: Option<String>

Allows grantee to list the objects in the bucket.

grant_read_acp: Option<String>

Allows grantee to read the bucket ACL.

grant_write: Option<String>

Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

grant_write_acp: Option<String>

Allows grantee to write the ACL for the applicable bucket.

object_lock_enabled_for_bucket: Option<bool>

Specifies whether you want S3 Object Lock to be enabled for the new bucket.