CreateBucketRequestBuilder

Struct CreateBucketRequestBuilder 

pub struct CreateBucketRequestBuilder { /* private fields */ }
Builder for CreateBucketRequest.

Implementations

Source

impl CreateBucketRequestBuilder

pub fn acl<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

The canned ACL to apply to the bucket.

pub fn bucket<VALUE: Into<String>>(self, value: VALUE) -> Self

The name of the bucket to create.

pub fn create_bucket_configuration<VALUE: Into<Option<CreateBucketConfiguration>>>( self, value: VALUE, ) -> Self

The configuration information for the bucket.

pub fn grant_full_control<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

pub fn grant_read<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Allows grantee to list the objects in the bucket.

pub fn grant_read_acp<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Allows grantee to read the bucket ACL.

pub fn grant_write<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

pub fn grant_write_acp<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Allows grantee to write the ACL for the applicable bucket.

pub fn object_lock_enabled_for_bucket<VALUE: Into<Option<bool>>>( self, value: VALUE, ) -> Self

Specifies whether you want S3 Object Lock to be enabled for the new bucket.

pub fn build( self, ) -> Result<CreateBucketRequest, CreateBucketRequestBuilderError>

Builds a new CreateBucketRequest.

Errors

If a required field has not been initialized.