pub struct DeleteObjectOutput {
pub delete_marker: Option<bool>,
pub request_charged: Option<String>,
pub version_id: Option<String>,
}Fields
delete_marker: Option<bool>Specifies whether the versioned object that was permanently deleted was (true) or was not (false) a delete marker.
request_charged: Option<String>version_id: Option<String>Returns the version ID of the delete marker created as a result of the DELETE operation.