DeleteObjectOutputBuilder

Struct DeleteObjectOutputBuilder 

pub struct DeleteObjectOutputBuilder { /* private fields */ }
Builder for DeleteObjectOutput.

Implementations

Source

impl DeleteObjectOutputBuilder

pub fn delete_marker<VALUE: Into<Option<bool>>>(self, value: VALUE) -> Self

Specifies whether the versioned object that was permanently deleted was (true) or was not (false) a delete marker.

pub fn request_charged<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

pub fn version_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Returns the version ID of the delete marker created as a result of the DELETE operation.

pub fn build(self) -> Result<DeleteObjectOutput, DeleteObjectOutputBuilderError>

Builds a new DeleteObjectOutput.

Errors

If a required field has not been initialized.