DeleteObjectRequestBuilder

Struct DeleteObjectRequestBuilder 

pub struct DeleteObjectRequestBuilder { /* private fields */ }
Builder for DeleteObjectRequest.

Implementations

Source

impl DeleteObjectRequestBuilder

pub fn bucket<VALUE: Into<String>>(self, value: VALUE) -> Self

The bucket name of the bucket containing the object. When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. When using this action with Amazon S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When using this action using S3 on Outposts through the AWS SDKs, you provide the Outposts bucket ARN in place of the bucket name. For more information about S3 on Outposts ARNs, see Using S3 on Outposts in the Amazon S3 User Guide.

pub fn bypass_governance_retention<VALUE: Into<Option<bool>>>( self, value: VALUE, ) -> Self

Indicates whether S3 Object Lock should bypass Governance-mode restrictions to process this operation.

pub fn expected_bucket_owner<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error.

pub fn key<VALUE: Into<String>>(self, value: VALUE) -> Self

Key name of the object to delete.

pub fn mfa<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

The concatenation of the authentication device’s serial number, a space, and the value that is displayed on your authentication device. Required to permanently delete a versioned object if versioning is configured with MFA delete enabled.

pub fn request_payer<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

pub fn version_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

VersionId used to reference a specific version of the object.

pub fn build( self, ) -> Result<DeleteObjectRequest, DeleteObjectRequestBuilderError>

Builds a new DeleteObjectRequest.

Errors

If a required field has not been initialized.