GetObjectRequestBuilder

Struct GetObjectRequestBuilder 

pub struct GetObjectRequestBuilder { /* private fields */ }
Builder for GetObjectRequest.

Implementations

Source

impl GetObjectRequestBuilder

pub fn bucket<VALUE: Into<String>>(self, value: VALUE) -> Self

The bucket name containing the object. When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. When using this action with Amazon S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When using this action using S3 on Outposts through the AWS SDKs, you provide the Outposts bucket ARN in place of the bucket name. For more information about S3 on Outposts ARNs, see Using S3 on Outposts in the Amazon S3 User Guide.

pub fn expected_bucket_owner<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error.

pub fn if_match<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Return the object only if its entity tag (ETag) is the same as the one specified, otherwise return a 412 (precondition failed).

pub fn if_modified_since<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Return the object only if it has been modified since the specified time, otherwise return a 304 (not modified).

pub fn if_none_match<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Return the object only if its entity tag (ETag) is different from the one specified, otherwise return a 304 (not modified).

pub fn if_unmodified_since<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Return the object only if it has not been modified since the specified time, otherwise return a 412 (precondition failed).

pub fn key<VALUE: Into<String>>(self, value: VALUE) -> Self

Key of the object to get.

pub fn part_number<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self

Part number of the object being read. This is a positive integer between 1 and 10,000. Effectively performs a ‘ranged’ GET request for the part specified. Useful for downloading just a part of an object.

pub fn range<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Downloads the specified range bytes of an object. For more information about the HTTP Range header, see https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35. Amazon S3 doesn't support retrieving multiple ranges of data per GET request.

pub fn request_payer<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

pub fn response_cache_control<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Sets the Cache-Control header of the response.

pub fn response_content_disposition<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Sets the Content-Disposition header of the response

pub fn response_content_encoding<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Sets the Content-Encoding header of the response.

pub fn response_content_language<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Sets the Content-Language header of the response.

pub fn response_content_type<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Sets the Content-Type header of the response.

pub fn response_expires<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Sets the Expires header of the response.

pub fn sse_customer_algorithm<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Specifies the algorithm to use to when decrypting the object (for example, AES256).

pub fn sse_customer_key<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Specifies the customer-provided encryption key for Amazon S3 used to encrypt the data. This value is used to decrypt the object when recovering it and must match the one used when storing the data. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header.

pub fn sse_customer_key_md5<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

pub fn version_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

VersionId used to reference a specific version of the object.

pub fn build(self) -> Result<GetObjectRequest, GetObjectRequestBuilderError>

Builds a new GetObjectRequest.

Errors

If a required field has not been initialized.