pub struct ObjectBuilder { /* private fields */ }Expand description
Builder for Object.
Implementations
Sourceimpl ObjectBuilder
impl ObjectBuilder
Sourcepub fn e_tag<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn e_tag<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
The entity tag is a hash of the object. The ETag reflects changes only to the contents of an object, not its metadata. The ETag may or may not be an MD5 digest of the object data. Whether or not it is depends on how the object was created and how it is encrypted as described below:
- Objects created by the PUT Object, POST Object, or Copy operation, or through the AWS Management Console, and are encrypted by SSE-S3 or plaintext, have ETags that are an MD5 digest of their object data.
- Objects created by the PUT Object, POST Object, or Copy operation, or through the AWS Management Console, and are encrypted by SSE-C or SSE-KMS, have ETags that are not an MD5 digest of their object data.
- If an object is created by either the Multipart Upload or Part Copy operation, the ETag is not an MD5 digest, regardless of the method of encryption.
Sourcepub fn key<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn key<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
The name that you assign to an object. You use the object key to retrieve the object.
Sourcepub fn last_modified<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn last_modified<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Creation date of the object.
Sourcepub fn storage_class<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn storage_class<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
The class of storage used to store the object.