pub struct PutObjectOutput {
pub bucket_key_enabled: Option<bool>,
pub e_tag: Option<String>,
pub expiration: Option<String>,
pub request_charged: Option<String>,
pub sse_customer_algorithm: Option<String>,
pub sse_customer_key_md5: Option<String>,
pub ssekms_encryption_context: Option<String>,
pub ssekms_key_id: Option<String>,
pub server_side_encryption: Option<String>,
pub version_id: Option<String>,
pub checksum: Option<String>,
}Fields
bucket_key_enabled: Option<bool>Indicates whether the uploaded object uses an S3 Bucket Key for server-side encryption with AWS KMS (SSE-KMS).
e_tag: Option<String>Entity tag for the uploaded object.
expiration: Option<String>If the expiration is configured for the object (see PutBucketLifecycleConfiguration), the response includes this header. It includes the expiry-date and rule-id key-value pairs that provide information about object expiration. The value of the rule-id is URL encoded.
request_charged: Option<String>sse_customer_algorithm: Option<String>If server-side encryption with a customer-provided encryption key was requested, the response will include this header confirming the encryption algorithm used.
sse_customer_key_md5: Option<String>If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide round-trip message integrity verification of the customer-provided encryption key.
ssekms_encryption_context: Option<String>If present, specifies the AWS KMS Encryption Context to use for object encryption. The value of this header is a base64-encoded UTF-8 string holding JSON with the encryption context key-value pairs.
ssekms_key_id: Option<String>If x-amz-server-side-encryption is present and has the value of
aws:kms, this header specifies the ID of the AWS Key Management
Service (AWS KMS) symmetric customer managed customer master key (CMK)
that was used for the object.
server_side_encryption: Option<String>If you specified server-side encryption either with an AWS KMS customer master key (CMK) or Amazon S3-managed encryption key in your PUT request, the response includes this header. It confirms the encryption algorithm that Amazon S3 used to encrypt the object.
version_id: Option<String>Version of the object.
checksum: Option<String>TODO