pub struct PutObjectOutputBuilder { /* private fields */ }Expand description
Builder for PutObjectOutput.
Implementations
Sourceimpl PutObjectOutputBuilder
impl PutObjectOutputBuilder
Sourcepub fn bucket_key_enabled<VALUE: Into<Option<bool>>>(self, value: VALUE) -> Self
pub fn bucket_key_enabled<VALUE: Into<Option<bool>>>(self, value: VALUE) -> Self
Indicates whether the uploaded object uses an S3 Bucket Key for server-side encryption with AWS KMS (SSE-KMS).
Sourcepub fn e_tag<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn e_tag<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Entity tag for the uploaded object.
Sourcepub fn expiration<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn expiration<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
If the expiration is configured for the object (see PutBucketLifecycleConfiguration), the response includes this header. It includes the expiry-date and rule-id key-value pairs that provide information about object expiration. The value of the rule-id is URL encoded.
pub fn request_charged<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Sourcepub fn sse_customer_algorithm<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn sse_customer_algorithm<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
If server-side encryption with a customer-provided encryption key was requested, the response will include this header confirming the encryption algorithm used.
Sourcepub fn sse_customer_key_md5<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn sse_customer_key_md5<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide round-trip message integrity verification of the customer-provided encryption key.
Sourcepub fn ssekms_encryption_context<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn ssekms_encryption_context<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
If present, specifies the AWS KMS Encryption Context to use for object encryption. The value of this header is a base64-encoded UTF-8 string holding JSON with the encryption context key-value pairs.
Sourcepub fn ssekms_key_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn ssekms_key_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
If x-amz-server-side-encryption is present and has the value of
aws:kms, this header specifies the ID of the AWS Key Management
Service (AWS KMS) symmetric customer managed customer master key (CMK)
that was used for the object.
Sourcepub fn server_side_encryption<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn server_side_encryption<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
If you specified server-side encryption either with an AWS KMS customer master key (CMK) or Amazon S3-managed encryption key in your PUT request, the response includes this header. It confirms the encryption algorithm that Amazon S3 used to encrypt the object.
Sourcepub fn version_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn version_id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Version of the object.